Module auto_refresh

Module auto_refresh 

Auto-refresh cache wrapper that proactively refreshes stale entries in the background, eliminating thundering-herd on cache miss.

Structs

AutoRefreshCache
A cache wrapper that refreshes entries in the background before they expire.