AutoRefreshCache

Struct AutoRefreshCache 

pub struct AutoRefreshCache<C, F, Fut>
where C: Cache + Clone + Send + Sync + 'static, F: Fn(String) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Vec<u8>, CacheError>> + Send + 'static,
{ /* private fields */ }
A cache wrapper that refreshes entries in the background before they expire.

When a get returns a None, the wrapper triggers a background refresh (via refresh_fn) while still returning the miss to the caller.

Implementations

Source

impl<C, F, Fut> AutoRefreshCache<C, F, Fut>
where C: Cache + Clone + Send + Sync + 'static, F: Fn(String) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Vec<u8>, CacheError>> + Send + 'static,

pub fn new(inner: C, refresh_fn: F, refresh_after: Duration) -> Self

Creates a new auto-refresh wrapper.

pub async fn get(&self, key: &str) -> Result<Option<Vec<u8>>, CacheError>

Gets a value, triggering a background refresh if the entry is a miss.

pub async fn set( &self, key: &str, value: Vec<u8>, ttl: Option<Duration>, ) -> Result<(), CacheError>

Sets a value in the underlying cache.

pub async fn invalidate(&self, key: &str) -> Result<(), CacheError>

Invalidates a key in the underlying cache.