A typed view over a byte cache using serde-compatible (JSON) encoding.
Only enabled with the cache-aside feature, which pulls in serde.
Structs
- Typed
Cache - Wraps a
Cachewith JSON-based typed get/set.
A typed view over a byte cache using serde-compatible (JSON) encoding.
Only enabled with the cache-aside feature, which pulls in serde.
Cache with JSON-based typed get/set.